## v0.1.2 (2024-08-15)

### Fix

- **scope**: remove trailing whitespace in body ([e7383d9](https://github.com/kmnhan/cz-changeup/commit/e7383d924051cc4b0eb0f4d7a61da32941d200d9))

[main 17702d2] bump: version 0.1.1 → 0.1.2
 2 files changed, 7 insertions(+), 1 deletion(-)

